@@ -1,4 +1,5 @@
 import mimetypes
+
 from django.conf import settings
 from django.core.exceptions import ImproperlyConfigured
 from django.core.files import File
@@ -12,22 +13,13 @@ except ImportError:
     raise ImproperlyConfigured("Could not load cloudfiles dependency. See "
                                "http://www.mosso.com/cloudfiles.jsp.")
 
+USERNAME = getattr(settings, 'CUMULUS_USERNAME')
+API_KEY = getattr(settings, 'CUMULUS_API_KEY')
+CONTAINER = getattr(settings, 'CUMULUS_CONTAINER')
+TIMEOUT = getattr(settings, 'CUMULUS_TIMEOUT', 5)
+USE_SERVICENET = getattr(settings, 'CUMULUS_USE_SERVICENET', False)
 # TODO: implement TTL into cloudfiles methods
-CUMULUS_TTL = getattr(settings, 'CUMULUS_TTL', 600)
-
-
-def cumulus_upload_to(self, filename):
-    """
-    Simple, custom upload_to because Cloud Files doesn't support
-    nested containers (directories).
-
-    Actually found this out from @minter:
-    @richleland The Cloud Files APIs do support pseudo-subdirectories, by
-    creating zero-byte files with type application/directory.
-
-    May implement in a future version.
-    """
-    return get_valid_filename(filename)
+TTL = getattr(settings, 'CUMULUS_TTL', 600)
 
 
 class CloudFilesStorage(Storage):
@@ -36,16 +28,19 @@ class CloudFilesStorage(Storage):
     """
     default_quick_listdir = True
 
-    def __init__(self, username=None, api_key=None, container=None,
+    def __init__(self, username=None, api_key=None, container=None, timeout=None,
                  connection_kwargs=None):
         """
         Initialize the settings for the connection and container.
         """
-        self.username = username or settings.CUMULUS_USERNAME
-        self.api_key = api_key or settings.CUMULUS_API_KEY
-        self.container_name = container or settings.CUMULUS_CONTAINER
+        self.username = username or USERNAME
+        self.api_key = api_key or API_KEY
+        self.container_name = container or CONTAINER
+        self.timeout = timeout or TIMEOUT
+        self.use_servicenet = USE_SERVICENET
         self.connection_kwargs = connection_kwargs or {}
 
+
     def __getstate__(self):
         """
         Return a picklable representation of the storage.
@@ -53,12 +48,18 @@ class CloudFilesStorage(Storage):
         return dict(username=self.username,
                     api_key=self.api_key,
                     container_name=self.container_name,
+                    timeout=self.timeout,
+                    use_servicenet=self.use_servicenet,
                     connection_kwargs=self.connection_kwargs)
 
     def _get_connection(self):
         if not hasattr(self, '_connection'):
-            self._connection = cloudfiles.get_connection(self.username,
-                                    self.api_key, **self.connection_kwargs)
+            self._connection = cloudfiles.get_connection(
+                                  username=self.username,
+                                  api_key=self.api_key,
+                                  timeout=self.timeout,
+                                  servicenet=self.use_servicenet,
+                                  **self.connection_kwargs)
         return self._connection
 
     def _set_connection(self, value):
@@ -119,6 +120,8 @@ class CloudFilesStorage(Storage):
         # getting the cloud object to try to guess.
         if hasattr(content.file, 'content_type'):
             cloud_obj.content_type = content.file.content_type
+        elif hasattr(content, 'content_type'):
+            cloud_obj.content = content.content_type
         else:
             mime_type, encoding = mimetypes.guess_type(name)
             cloud_obj.content_type = mime_type
